==> aana-0.2.0-py3-none-any.whl: aana/core/models/chat.py <==
from typing import Annotated, Literal

from pydantic import BaseModel, ConfigDict, Field

Role = Literal["system", "user", "assistant"]

Prompt = Annotated[str, Field(description="The prompt for the LLM.")]

Question = Annotated[str, Field(description="The question.")]


class ChatMessage(BaseModel):
    """A chat message.

    Attributes:
        content (str): the text of the message
        role (Role): the role of the message
    """

    content: str
    role: Role
    model_config = ConfigDict(
        json_schema_extra={
            "description": "A chat message.",
            "examples": [
                {
                    "role": "system",
                    "content": "You are a helpful assistant.",
                },
                {
                    "role": "user",
                    "content": "Hello, how are you?",
                },
                {
                    "role": "assistant",
                    "content": "I am doing well, thank you.",
                },
            ],
        }
    )


class ChatDialog(BaseModel):
    """A chat dialog.

    Attributes:
        messages (list[ChatMessage]): the messages in the dialog
    """

    messages: list[ChatMessage]
    model_config = ConfigDict(
        json_schema_extra={
            "description": "A chat dialog.",
            "examples": [
                {
                    "messages": [
                        {
                            "role": "system",
                            "content": "You are a helpful assistant.",
                        },
                        {
                            "role": "user",
                            "content": "Hello, how are you?",
                        },
                        {
                            "role": "assistant",
                            "content": "I am doing well, thank you.",
                        },
                    ]
                }
            ],
        }
    )

    @classmethod
    def from_list(cls, messages: list[dict[str, str]]) -> "ChatDialog":
        """Create a ChatDialog from a list of dictionaries.

        Args:
            messages (list[dict[str, str]]): the list of messages

        Returns:
            ChatDialog: the chat dialog
        """
        return ChatDialog(messages=[ChatMessage(**message) for message in messages])


class ChatCompletionRequest(BaseModel):
    """A chat completion request for OpenAI compatible API."""

    model: str = Field(..., description="The model name (name of the LLM deployment).")
    messages: list[ChatMessage] = Field(
        ..., description="A list of messages comprising the conversation so far."
    )
    temperature: float | None = Field(
        default=None,
        ge=0.0,
        description=(
            "Float that controls the randomness of the sampling. "
            "Lower values make the model more deterministic, "
            "while higher values make the model more random. "
            "Zero means greedy sampling."
        ),
    )
    top_p: float | None = Field(
        default=None,
        gt=0.0,
        le=1.0,
        description=(
            "Float that controls the cumulative probability of the top tokens to consider. "
            "Must be in (0, 1]. Set to 1 to consider all tokens."
        ),
    )
    max_tokens: int | None = Field(
        default=None, ge=1, description="The maximum number of tokens to generate."
    )

    stream: bool | None = Field(
        default=False,
        description=(
            "If set, partial message deltas will be sent, like in ChatGPT. "
            "Tokens will be sent as data-only server-sent events as they become available, "
            "with the stream terminated by a data: [DONE] message."
        ),
    )


class ChatCompletetionChoice(BaseModel):
    """A chat completion choice for OpenAI compatible API."""

    index: int = Field(
        ..., description="The index of the choice in the list of choices."
    )
    message: ChatMessage = Field(
        ..., description="A chat completion message generated by the model."
    )


class ChatCompletetion(BaseModel):
    """A chat completion for OpenAI compatible API."""

    id: str = Field(..., description="A unique identifier for the chat completion.")
    model: str = Field(..., description="The model used for the chat completion.")
    created: int = Field(
        ...,
        description="The Unix timestamp (in seconds) of when the chat completion was created.",
    )
    choices: list[ChatCompletetionChoice] = Field(
        ...,
        description="A list of chat completion choices.",
    )
    object: Literal["chat.completion"] = Field(
        "chat.completion",
        description="The object type, which is always `chat.completion`.",
    )

==> aana-0.2.2-py3-none-any.whl: aana/core/models/chat.py <==
from typing import Annotated, Literal

from pydantic import BaseModel, ConfigDict, Field

__all__ = [
    "Role",
    "Prompt",
    "Question",
    "ChatMessage",
    "ChatDialog",
    "ChatCompletionRequest",
    "ChatCompletionChoice",
    "ChatCompletion",
]

Role = Literal["system", "user", "assistant"]
"""
The role of a participant in a conversation.

- "system": Used for instructions or context provided to the model.
- "user": Represents messages from the user.
- "assistant": Represents LLM responses.
"""

Prompt = Annotated[str, Field(description="The prompt for the LLM.")]
"""
The prompt for the LLM.
"""

Question = Annotated[str, Field(description="The question.")]
"""
The question.
"""


class ChatMessage(BaseModel):
    """A chat message.

    Attributes:
        content (str): the text of the message
        role (Role): the role of the message
    """

    content: str
    role: Role
    model_config = ConfigDict(
        json_schema_extra={
            "description": "A chat message.",
            "examples": [
                {
                    "role": "system",
                    "content": "You are a helpful assistant.",
                },
                {
                    "role": "user",
                    "content": "Hello, how are you?",
                },
                {
                    "role": "assistant",
                    "content": "I am doing well, thank you.",
                },
            ],
        }
    )


class ChatDialog(BaseModel):
    """A chat dialog.

    Attributes:
        messages (list[ChatMessage]): the messages in the dialog
    """

    messages: list[ChatMessage]
    model_config = ConfigDict(
        json_schema_extra={
            "description": "A chat dialog.",
            "examples": [
                {
                    "messages": [
                        {
                            "role": "system",
                            "content": "You are a helpful assistant.",
                        },
                        {
                            "role": "user",
                            "content": "Hello, how are you?",
                        },
                        {
                            "role": "assistant",
                            "content": "I am doing well, thank you.",
                        },
                    ]
                }
            ],
        }
    )

    @classmethod
    def from_list(cls, messages: list[dict[str, str]]) -> "ChatDialog":
        """Create a ChatDialog from a list of dictionaries.

        Args:
            messages (list[dict[str, str]]): the list of messages

        Returns:
            ChatDialog: the chat dialog
        """
        return ChatDialog(messages=[ChatMessage(**message) for message in messages])

    @classmethod
    def from_prompt(cls, prompt: str) -> "ChatDialog":
        """Create a ChatDialog from a prompt.

        Args:
            prompt (str): the prompt

        Returns:
            ChatDialog: the chat dialog
        """
        return ChatDialog(messages=[ChatMessage(content=prompt, role="user")])


class ChatCompletionRequest(BaseModel):
    """A chat completion request for OpenAI compatible API.

    Attributes:
        model (str): the model name (name of the LLM deployment)
        messages (list[ChatMessage]): a list of messages comprising the conversation so far
        temperature (float): float that controls the randomness of the sampling
        top_p (float): float that controls the cumulative probability of the top tokens to consider
        max_tokens (int): the maximum number of tokens to generate
        stream (bool): if set, partial message deltas will be sent
    """

    model: str = Field(..., description="The model name (name of the LLM deployment).")
    messages: list[ChatMessage] = Field(
        ..., description="A list of messages comprising the conversation so far."
    )
    temperature: float | None = Field(
        default=None,
        ge=0.0,
        description=(
            "Float that controls the randomness of the sampling. "
            "Lower values make the model more deterministic, "
            "while higher values make the model more random. "
            "Zero means greedy sampling."
        ),
    )
    top_p: float | None = Field(
        default=None,
        gt=0.0,
        le=1.0,
        description=(
            "Float that controls the cumulative probability of the top tokens to consider. "
            "Must be in (0, 1]. Set to 1 to consider all tokens."
        ),
    )
    max_tokens: int | None = Field(
        default=None, ge=1, description="The maximum number of tokens to generate."
    )

    stream: bool | None = Field(
        default=False,
        description=(
            "If set, partial message deltas will be sent, like in ChatGPT. "
            "Tokens will be sent as data-only server-sent events as they become available, "
            "with the stream terminated by a data: [DONE] message."
        ),
    )


class ChatCompletionChoice(BaseModel):
    """A chat completion choice for OpenAI compatible API.

    Attributes:
        index (int): the index of the choice in the list of choices
        message (ChatMessage): a chat completion message generated by the model
    """

    index: int = Field(
        ..., description="The index of the choice in the list of choices."
    )
    message: ChatMessage = Field(
        ..., description="A chat completion message generated by the model."
    )


class ChatCompletion(BaseModel):
    """A chat completion for OpenAI compatible API.

    Attributes:
        id (str): a unique identifier for the chat completion
        model (str): the model used for the chat completion
        created (int): the Unix timestamp (in seconds) of when the chat completion was created
        choices (list[ChatCompletionChoice]): a list of chat completion choices
        object (Literal["chat.completion"]): the object type, which is always `chat.completion`
    """

    id: str = Field(..., description="A unique identifier for the chat completion.")
    model: str = Field(..., description="The model used for the chat completion.")
    created: int = Field(
        ...,
        description="The Unix timestamp (in seconds) of when the chat completion was created.",
    )
    choices: list[ChatCompletionChoice] = Field(
        ...,
        description="A list of chat completion choices.",
    )
    object: Literal["chat.completion"] = Field(
        "chat.completion",
        description="The object type, which is always `chat.completion`.",
    )
